@@ -804,8 +804,12 @@ def cancel_progress(key):
         lock.acquire()
         if key in compressionProgress:
             compressionProgress[key]['progress'] = -1
+        else:
+            compressionProgress[key] = { 'progress': -1 }
         if key in uploadProgress:
             uploadProgress[key]['progress'] = -1
+        else:
+            uploadProgress[key] = { 'progress': -1 }
     except:
         pass
     finally:
@@ -1455,6 +1459,20 @@ def upload_files(key, paths, compress):
             if not exists:
                 filesToUpload.append((file, os.path.getsize(file)))
         
+        # Check if the user aborted while we were getting file sizes, setting things up
+        try:
+            lock.acquire()
+            if key in compressionProgress:
+                # Handle the case where compression was canceled
+                if compressionProgress[key]['progress'] == -1:
+                    raise CancelledError("Compression cancelled")
+        except CancelledError as e:
+            raise e
+        except Exception as e:
+            pass
+        finally:
+            lock.release()
+
         if len(filesToUpload) > 0:
             # Sort by file size
             filesToUpload.sort(key=lambda x:x[1], reverse=True)
@@ -1473,8 +1491,22 @@ def upload_files(key, paths, compress):
             fileChunks = [[]]
             totalSize = 0
             for file, size in filesToUpload:
+                # Check if the user aborted before we process and potentially compress a new file
+                try:
+                    lock.acquire()
+                    if key in compressionProgress:
+                        # Handle the case where compression was canceled
+                        if compressionProgress[key]['progress'] == -1:
+                            raise CancelledError("Compression cancelled")
+                except CancelledError as e:
+                    raise e
+                except Exception as e:
+                    pass
+                finally:
+                    lock.release()
+
                 if size > MAX_SIZE:
-                    # TODO:JJ We should let the user know we can;t upload a file because it is too large
+                    # TODO:JJ We should let the user know we can't upload a file because it is too large
                     continue
                 elif totalSize + size > MAX_SIZE:
                     # If the next file takes us over 5GB, this is the end of the chunk
@@ -1499,9 +1531,14 @@ def upload_files(key, paths, compress):
                     totalSize += os.path.getsize(file)
             try:
                 lock.acquire()
-                if key in compressionProgress: 
+                if key in compressionProgress:
+                    # Handle the case where compression was canceled
+                    if compressionProgress[key]['progress'] == -1:
+                        raise CancelledError("Compression cancelled")
                     compressionProgress[key]['progress'] = -1
                 uploadProgress[key] = { 'progress': 0, 'total': totalSize }
+            except CancelledError as e:
+                raise e
             except Exception as e:
                 pass
             finally:
