@@ -95,7 +95,8 @@ export class UserDialog extends React.Component<IProps, IState> {
 		const init: RequestInit = {
 			method: 'POST',
 			body: JSON.stringify({
-				uuid: app.uuid,
+				workload: app.uuid,
+				module: app.modules[0].uuid,
 			}),
 		};
 		ServerConnection.makeRequest(
@@ -264,11 +265,11 @@ export class UserDialog extends React.Component<IProps, IState> {
                                 padding: '0px',
                             }}>
                                 <div style={{
-                                    display: 'flex',
-                                    flexDirection: 'column',
-                                    padding: '6px',
-                                    height: '100%',
-                                }}>
+									display: 'flex',
+									flexDirection: 'column',
+									padding: '6px',
+									height: '100%',
+								}}>
                                     <Tabs
                                         value={this.state.selectedPanel}
                                         onChange={(event, newValue) => this.safeSetState({selectedPanel: newValue})}
@@ -314,7 +315,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                             }}
                                             value={Page.PAYMENT}
                                         />
-                                        {/* <Tab
+                                        <Tab
                                             label='FILES'
                                             style={{
                                                 padding: '0px',
@@ -322,15 +323,15 @@ export class UserDialog extends React.Component<IProps, IState> {
                                                 minHeight: '36px',
                                             }}
                                             value={Page.FILES}
-                                        /> */}
+                                        />
                                     </Tabs>
                                     <div style={{
-                                        margin: '12px',
-                                        color: 'var(--jp-ui-font-color3)',
-                                        textAlign: 'center',
-                                        fontSize: '10px',
-                                        fontStyle: 'italic',
-                                    }}>
+										margin: '12px',
+										color: 'var(--jp-ui-font-color3)',
+										textAlign: 'center',
+										fontSize: '10px',
+										fontStyle: 'italic',
+									}}>
                                         Version {Global.version}
                                     </div>
                                 </div>
