@@ -29,6 +29,7 @@ import { NotificationsPopup } from './NotificationsPopup';
 import ExtraInfo from '../../utils/ExtraInfo';
 import FormatUtils from '../../utils/FormatUtils';
 import { InfoPopup } from '../../core/InfoPoppup';
+import WarningPopup from '../../core/WarningPopup';
 // import { EmbeddedYoutube } from '../../core/EmbeddedYoutube';
 
 // const emDirNotFile = 'Path is a directory, not a file'
@@ -104,6 +105,7 @@ interface IState {
     // Here is where we will keep a list of the file paths that were entered successfully but no longer exist on the disk
     problemFiles: string[]
     problemDataConnectors: string[]
+    filesTooBig: FileMetadata[]
 }
 
 class FilesPanel extends React.Component<IProps, IState> {
@@ -123,6 +125,7 @@ class FilesPanel extends React.Component<IProps, IState> {
             filePath: '',
             problemFiles: [],
             problemDataConnectors: [],
+            filesTooBig: [],
         }
     }
 
@@ -333,7 +336,23 @@ class FilesPanel extends React.Component<IProps, IState> {
                     </StyledAccordionSummary>
                     <StyledAccordionDetails>
                         <div style={{display: 'inline-flex', width: '100%'}}>
+                            <WarningPopup
+                                open={this.state.filesTooBig.length > 0}
+                                headerText="Warning"
+                                bodyText={(() => {
+                                    const problems = this.state.filesTooBig.map(x => x.path + ' (' + FormatUtils.styleCapacityUnitValue()(x.size) + ')').join('\n')
+                                    return `The following files exceed the maximum upload size (2 GiB):\n\n` + problems + `\n\nTo access larger data, use data connectors.`
+                                })()}
+                                continue={{
+                                    text: `Ok`,
+                                    onContinue: (prevent: boolean) => {
+                                        this.safeSetState({ filesTooBig: [] })
+                                    },
+                                    color: `error`,
+                                }}
+                            />
                             <AddFilesPopup onFilesAdded={async (metadatas: FileMetadata[]) => {
+                                const filesTooBig = [];
                                 for (let fileModel of metadatas) {
                                     // Don't try to add the same file/directory more than once
                                     if (this.pathHasError(fileModel.path)) continue;
@@ -341,23 +360,41 @@ class FilesPanel extends React.Component<IProps, IState> {
                                     const optumi = tracker.getMetadata()
                                     var files = optumi.config.upload.files
                                     if (fileModel.type != 'directory') {
-                                        files.push(new FileUploadConfig({
-                                            path: fileModel.path,
-                                            type: fileModel.type,
-                                            mimetype: fileModel.mimetype,
-                                            files: [fileModel.path]
-                                        }))
+                                        if (fileModel.size > Global.MAX_UPLOAD_SIZE) {
+                                            filesTooBig.push(fileModel);
+                                        } else {
+                                            files.push(new FileUploadConfig({
+                                                path: fileModel.path,
+                                                type: fileModel.type,
+                                                mimetype: fileModel.mimetype,
+                                                files: [fileModel.path]
+                                            }))
+                                        }
                                     } else {
-                                        files.push(new FileUploadConfig({
-                                            path: fileModel.path,
-                                            type: fileModel.type,
-                                            mimetype: fileModel.mimetype,
-                                            files: (await FileServerUtils.getRecursiveTree(fileModel.path))
-                                        }))
+                                        const directoryContents = (await FileServerUtils.getRecursiveTree(fileModel.path))
+                                        const directoryPaths = []
+                                        for (let metadata of directoryContents) {
+                                            if (metadata.size > Global.MAX_UPLOAD_SIZE) {
+                                                filesTooBig.push(metadata);
+                                            } else {
+                                                directoryPaths.push(metadata.path);
+                                            }
+                                        }
+                                        if (directoryPaths.length > 0) {
+                                            files.push(new FileUploadConfig({
+                                                path: fileModel.path,
+                                                type: fileModel.type,
+                                                mimetype: fileModel.mimetype,
+                                                files: directoryPaths,
+                                            }))
+                                        }
                                     }
                                     tracker.setMetadata(optumi)
                                     Global.user.fileTracker.uploadFiles(fileModel)
                                 }
+                                if (filesTooBig.length > 0) {
+                                    this.safeSetState({ filesTooBig: filesTooBig })
+                                }
                             }} />
                             <AddDataConnectorsPopup openUserDialogTo={this.props.openUserDialogTo}
 								onDataConnectorsAdded={async (metadatas: DataConnectorMetadata[]) => {
