@@ -8,7 +8,7 @@
 import * as React from 'react';
 import { Global } from '../../Global';
 import withStyles, { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { Button } from '@material-ui/core';
+import { Button, lighten } from '@material-ui/core';
 
 import RadioButtonUncheckedIcon from '@material-ui/icons/RadioButtonUnchecked';
 import CheckCircleIcon from '@material-ui/icons/CheckCircle';
@@ -17,7 +17,7 @@ interface IProps {
     style?: CSSProperties
     label: string
     selected: boolean
-    hexColor: string
+    color: string
     beta?: boolean
     handleClick: () => string | void
     onMouseOver?: (event: React.MouseEvent<HTMLDivElement, MouseEvent>) => void
@@ -33,7 +33,7 @@ export class OutlinedResourceRadio extends React.Component<IProps, IState> {
 
     constructor(props: IProps) {
         super(props);
-        this.StyledButton = this.getStyledButton(this.props.hexColor);
+        this.StyledButton = this.getStyledButton(this.props.color);
     }
 
     private handleMouseOver = (event: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
@@ -51,8 +51,8 @@ export class OutlinedResourceRadio extends React.Component<IProps, IState> {
                 fontWeight: 'normal',
                 display: 'inline-flex',
                 padding: '6px',
-                height: '34px',
-                border: '2px solid ' + color + '80',
+                height: '28px',
+                border: '1px solid ' + color + '80',
                 borderRadius: '6px',
                 margin: '0px 6px 6px 6px',
                 width: 'calc(100% - 12px)',
@@ -60,8 +60,8 @@ export class OutlinedResourceRadio extends React.Component<IProps, IState> {
                 overflow: 'hidden',
                 position: 'relative',
                 '&:hover': {
-                    border: '2px solid ' + color + '80',
-                    backgroundColor: color + '40'
+                    border: '1px solid ' + lighten(color, 0.5),
+                    backgroundColor: lighten(color, 0.75),
                 },
             },
         }) (Button)
@@ -72,8 +72,8 @@ export class OutlinedResourceRadio extends React.Component<IProps, IState> {
         return (
             <this.StyledButton
                 style={Object.assign({
-                    border: this.props.selected ? '2px solid ' + this.props.hexColor : '',
-                    backgroundColor: this.props.selected ? this.props.hexColor + '40' : '',
+                    border: this.props.selected ? '1px solid ' + this.props.color : '',
+                    backgroundColor: this.props.selected ? this.props.color + '40' : '',
                 }, this.props.style)}
                 onClick={() => this.props.handleClick()}
                 onMouseOver={this.handleMouseOver}
@@ -92,7 +92,7 @@ export class OutlinedResourceRadio extends React.Component<IProps, IState> {
                     <CheckCircleIcon
                         fontSize='small'
                         style={{
-                            fill: this.props.hexColor,
+                            fill: this.props.color,
                             margin: 'auto',
                         }}
                     />
@@ -100,7 +100,7 @@ export class OutlinedResourceRadio extends React.Component<IProps, IState> {
                     <RadioButtonUncheckedIcon
                         fontSize='small'
                         style={{
-                            fill: this.props.hexColor + '80',
+                            fill: this.props.color + '80',
                             margin: 'auto',
                         }}
                     />
@@ -111,7 +111,7 @@ export class OutlinedResourceRadio extends React.Component<IProps, IState> {
                         left: '-22px',
                         top: '3px',
                         transform: 'rotate(-45deg)',
-                        background: this.props.selected ? this.props.hexColor : this.props.hexColor + '80',
+                        background: this.props.selected ? this.props.color : this.props.color + '80',
                         color: '#ffffff',
                         fontSize: '9px',
                         lineHeight: '14px',
