@@ -133,6 +133,7 @@ export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGener
                                             this.stringToCSVCell(app.annotationOrRunNum),
                                             app.timestamp,
                                             app.getTimeElapsed(),
+                                            app.interactive ? 'N/A' : app.notebook.metadata.papermill.duration,
                                             app.getCost(),
                                             app.getAppMessage(),
                                             machine.name,
@@ -170,7 +171,7 @@ export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGener
                                 }
             
                                 const headers = [
-                                    ["Name", "Annotation", "Start Time", "Duration", "Cost", "Status", "Machine", "Cores", "RAM", "Disk", "GPUs", "UUID"]
+                                    ["Name", "Annotation", "Start Time", "Duration (total)", "Duration (notebook)", "Cost", "Status", "Machine", "Cores", "RAM", "Disk", "GPUs", "UUID"]
                                 ];
             
                                 var link = document.createElement("a");
