@@ -74,8 +74,8 @@ export class Dropdown extends React.Component<IProps, IState> {
                 display: 'inline-flex',
                 width: '100%',
                 padding: '6px 0px',
-                textAlign: 'center',
-                justifyContent: 'center'
+                // textAlign: 'center',
+                // justifyContent: 'center'
             }, this.props.style)}>
                 {this.props.label && <div style={{
                     minWidth: this.props.labelWidth || '68px',
