@@ -7,7 +7,7 @@
 
 import * as React from 'react';
 import { Global } from '../Global';
-import { Slider, withStyles, darken, lighten } from '@material-ui/core';
+import { Slider, withStyles } from '@material-ui/core';
 import { Eco, Equalizer, FlashOn } from '@material-ui/icons';
 
 interface IProps {
@@ -35,7 +35,6 @@ export class IntentSlider extends React.Component<IProps, IState> {
     private _isMounted = false;
 
     private StyledSlider: any;
-    private isLightMode: boolean = false;
 
     public constructor(props: IProps) {
         super (props);
@@ -46,12 +45,12 @@ export class IntentSlider extends React.Component<IProps, IState> {
     }
 
     private getStyledSlider = () => {
-        this.isLightMode = Global.themeManager == undefined || Global.themeManager.isLight(Global.themeManager.theme)
         return withStyles({
             root: {
                 height: '16px',
-                width: '100%',
+                width: 'calc(100% - 42px)',
                 padding: '13px 0px',
+                margin: '0px 21px'
             },
             thumb: { // hidden
                 position: 'relative',
@@ -91,16 +90,16 @@ export class IntentSlider extends React.Component<IProps, IState> {
                 color: this.props.color,
                 opacity: 0,
                 boxSizing: 'border-box',
-                border: "1px solid " + darken(this.props.color, 0.25),
+                // border: "1px solid " + darken(this.props.color, 0.25),
                 borderRadius: '8px',
             },
             rail: { // right side
                 height: '16px',
                 width: '100%',
                 opacity: 1,
-                color: (this.isLightMode ? '#eeeeee' : '#424242'),
+                color: 'var(--jp-layout-color2)',
                 boxSizing: 'border-box',
-                border: '1px solid ' + (this.isLightMode ? darken('#eeeeee', 0.25) : lighten('#424242', 0.25)),
+                // border: '1px solid ' + (this.isLightMode ? darken('#eeeeee', 0.25) : lighten('#424242', 0.25)),
                 borderRadius: '8px',
             },
             mark: {
@@ -169,19 +168,29 @@ export class IntentSlider extends React.Component<IProps, IState> {
                         max={100}
                         value={this.state.value * 100}
                         ThumbComponent={(props: any) => (
-                            <span style={{transform: 'translate(' + (50 - (100 * this.state.value)) + '%, 0px)', left: this.state.value + '%'}} {...props}>
+                            <span style={Object.assign({transform: 'translate(' + (50 - (100 * this.state.value)) + '%, 0px)', left: this.state.value + '%'}, props.style)} {...props}>
                                 {icons[icon]}
                             </span>
                         )}
                     />
+                    <div style={{
+                            position: 'absolute', 
+                            top: 'calc(50% - 8px)', 
+                            left: '0px', 
+                            width: '100%',
+                            backgroundColor: 'var(--jp-layout-color2)',
+                            height: '16px',
+                            borderRadius: '8px',
+                        }}
+                    />
                     <div style={{
                             position: 'absolute', 
                             zIndex: 1,
                             top: 'calc(50% - 8px)', 
                             left: '12px', 
-                            color: (this.isLightMode ? '#424242' : '#eeeeee'), 
+                            color: 'var(--jp-ui-font-color1)',
                             fontSize: '11px',
-                            opacity: this.state.value < 0.37 ? 0 : 1,
+                            opacity: this.state.value < 0.22 ? 0 : 1,
                             transition: 'opacity 250ms ease 0s',
                             fontStyle: 'italic',
                             height: '0px', overflow: 'visible', pointerEvents: 'none' // Pass click events to the slider behind
@@ -194,9 +203,9 @@ export class IntentSlider extends React.Component<IProps, IState> {
                             zIndex: 1,
                             top: 'calc(50% - 8px)', 
                             right: '12px', 
-                            color: (this.isLightMode ? '#424242' : '#eeeeee'), 
+                            color: 'var(--jp-ui-font-color1)',
                             fontSize: '11px',
-                            opacity: this.state.value > 0.7 ? 0 : 1,
+                            opacity: this.state.value > 0.82 ? 0 : 1,
                             transition: 'opacity 250ms ease 0s',
                             fontStyle: 'italic',
                             height: '0px', overflow: 'visible', pointerEvents: 'none' // Pass click events to the slider behind    
@@ -210,22 +219,16 @@ export class IntentSlider extends React.Component<IProps, IState> {
     }
 
     private handleMetadataChange = () => this.safeSetState({ value: this.props.getValue(), weGotADot: '' })
-    private handleThemeChange = () => {
-        this.StyledSlider = this.getStyledSlider();
-        if (this._isMounted) this.forceUpdate();
-    }
 
     // Will be called automatically when the component is mounted
 	public componentDidMount = () => {
 		this._isMounted = true;
         Global.metadata.getMetadataChanged().connect(this.handleMetadataChange);
-        Global.themeManager.themeChanged.connect(this.handleThemeChange);
 	}
 
 	// Will be called automatically when the component is unmounted
 	public componentWillUnmount = () => {
 		Global.metadata.getMetadataChanged().disconnect(this.handleMetadataChange);
-        Global.themeManager.themeChanged.disconnect(this.handleThemeChange);
 		this._isMounted = false;
     }
     
