@@ -25,8 +25,21 @@ export default class CodeCell extends React.Component<IProps, IState> {
         return (
             <div className='p-Widget lm-Widget jp-Cell jp-CodeCell jp-Notebook-cell' onContextMenu={(e) => e.preventDefault()}>
                 <InputArea cell={this.props.cell} metadata={this.props.metadata} renderInColor={this.props.renderInColor} />
-                <OutputArea cell={this.props.cell} metadata={this.props.metadata} />
+                {this.props.cell.outputs && this.props.cell.outputs.length > 0 && (
+                    <OutputArea cell={this.props.cell} metadata={this.props.metadata} />
+                )}
             </div>
         )
     }
+
+    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+        try {
+            if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
+            if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
+            return false;
+        } catch (error) {
+            return true;
+        }
+    }
 }
