@@ -41,7 +41,18 @@ export default class Notebook extends React.Component<IProps, IState> {
         )
     }
 
+    private papermillErrorCell: HTMLElement = null
     public componentDidMount = () => {
+        // Remove the papermill error cell from any elements if they exist
+        this.papermillErrorCell = document.getElementById('papermill-error-cell');
+        if (this.papermillErrorCell) {
+            this.papermillErrorCell.id = ''
+            // Avoid removing the id from the notebook in the popup
+            if (!document.getElementById('papermill-error-cell')) {
+                this.papermillErrorCell.id = 'papermill-error-cell';
+                this.papermillErrorCell = null;
+            }
+        }
         // Scroll to the current executing cell if there is one running
         location.href = "#";
         location.href = "#scrollHere";
@@ -54,6 +65,11 @@ export default class Notebook extends React.Component<IProps, IState> {
     public componentWillUnmount = () => {
         // Restore the old JupyterLab context menu open
         Global.lab.contextMenu.open = this.oldOpen;
+        // Restore the old error cell
+        if (this.papermillErrorCell) {
+            this.papermillErrorCell.id = 'papermill-error-cell';
+            this.papermillErrorCell = null;
+        }
     }
 
     public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
