@@ -118,8 +118,10 @@ export class FileTracker {
 
         const paths = [];
         if (metadata.type == 'directory') {
-            for (var file of (await FileServerUtils.getRecursiveTree(metadata.path))) {
-                paths.push(file);
+            for (let file of (await FileServerUtils.getRecursiveTree(metadata.path))) {
+                if (file.size <= Global.MAX_UPLOAD_SIZE) {
+                    paths.push(file.path);
+                }
             }
         } else {
             paths.push(metadata.path);
