@@ -20,7 +20,6 @@ export class GraphicsConfig {
     public memory: number[];
     public frequency: number[];
     // Dev Ops properties
-    public boardCount: number[];
     public boardType: string;
 
     constructor(map: any = {}, user: User = null) {
@@ -31,7 +30,6 @@ export class GraphicsConfig {
         this.cores = map.cores || [-1, -1, -1];
         this.memory = map.memory || [-1, -1, -1];
         this.frequency = map.frequency || [-1, -1, -1];
-        this.boardCount = map.boardCount || [1, -1, -1];
-        this.boardType = map.boardType || "K80";
+        this.boardType = map.boardType || "U";  // Default is U for unspecified
     }
 }
\ No newline at end of file
