@@ -38,8 +38,10 @@ export class Module {
     private _output: Update[];
     private _files: FileMetadata[];
     private _updates: Update[];
+    private _monitoring: Update[];
+	private _updateCallback: ((update: any) => void)[] = [];
 
-	constructor(uuid: string, machine: Machine = null, sessionToken: string = null, output: Update[] = [], updates: Update[] = [], files: FileMetadata[] = [], lastPatch: number = 0) {
+	constructor(uuid: string, machine: Machine = null, sessionToken: string = null, output: Update[] = [], updates: Update[] = [], files: FileMetadata[] = [], monitoring: Update[] = [], lastPatch: number = 0) {
 		this._uuid = uuid;
 
 		this._sessionToken = sessionToken;
@@ -51,6 +53,7 @@ export class Module {
 
 		this._updates = updates;
 		this._files = files;
+		this._monitoring = monitoring;
 
 		this._lastPatch = lastPatch;
 	}
@@ -91,6 +94,10 @@ export class Module {
 		return this._files;
 	}
 
+	get monitoring(): Update[] {
+        return this._monitoring;
+    }
+
 	get modStatus(): Status {
 		for (var update of this._updates) {
 			if (update.modifier == "stop") return Status.COMPLETED;
@@ -105,6 +112,14 @@ export class Module {
 		return false;
     }
 
+	public addUpdateCallback(callback: (update: any) => void) {
+		this._updateCallback.push(callback)
+	}
+
+	public removeUpdateCallback(callback: (update: any) => void) {
+		this._updateCallback = this._updateCallback.filter(obj => obj !== callback)
+	}
+
 	public handleUpdate(body: any): boolean {
 		let updated = false
 		if (body.output != null) {
@@ -152,6 +167,7 @@ export class Module {
 						path: body.files[i],
 						size: +body.filessize[i],
 						type: 'file',
+						hash: body.hashes[i]
 					} as FileMetadata);
 				}
 			}
@@ -176,6 +192,16 @@ export class Module {
 			updated = true;
 			this._machine = Object.setPrototypeOf(body.machine, Machine.prototype);
 		}
+		if (body.monitoring != null) {
+			if (body.monitoring.length > 0) updated = true;
+			for (let i = 0; i < body.monitoring.length; i++) {
+				const update = new Update(body.monitoring[i], body.monitoringmod[i]);
+				this._monitoring.push(update);
+				for (let callback of this._updateCallback) {
+					callback(update)
+				}
+			}
+		}
 		return updated;
 	}
 
