@@ -80,6 +80,14 @@ export class OptumiConfig {
 			case "3.6.0":
 			case "3.7.0":
 			case "3.7.1":
+			case "3.7.2":
+			case "3.7.3":
+			case "3.8.0":
+			case "3.8.1":
+			case "3.8.2":
+			case "3.8.3":
+			case "3.8.4":
+			case "3.9.0":
 				break;
 			default:
 				if (!version.includes("DEV")) console.log("Unknown map version: " + version);
@@ -92,7 +100,7 @@ export class OptumiConfig {
         this.storage = new StorageConfig(map.storage || {});
 		this.upload = new UploadConfig(map.upload || {});
 		this.notifications = new NotificationConfig(map.notifications || {});
-		this.interactive = map.interactive == undefined ? true : map.interactive;
+		this.interactive = map.interactive == undefined ? false : map.interactive;
 		this.annotation = map.annotation || "";
 	}
 
