@@ -272,7 +272,11 @@ export class App {
 			if (cell.outputs) {
 				for (var output of cell.outputs) {
 					if (output.text) {
-						output.text = (output.text as string[]).join('');
+						if (Array.isArray(output.text)) {
+							output.text = (output.text as string[]).join('');
+						} else {
+							output.text = output.text.toString()
+						}
 					}
 				}
 			}
@@ -569,7 +573,7 @@ export class App {
 		for (var uploadEntry of uploadFiles) {
 			if (uploadEntry.type == 'directory') {
 				for (var file of (await FileServerUtils.getRecursiveTree(uploadEntry.path))) {
-					data.paths.push(file);
+					data.paths.push(file.path);
 				}
 			} else {
 				data.paths.push(uploadEntry.path);
