@@ -25,6 +25,7 @@ import FileServerUtils from '../../utils/FileServerUtils';
 import { NotificationContent } from '../../core/NotificationContent';
 import { OptumiConfig } from '../OptumiConfig';
 import ExtraInfo from '../../utils/ExtraInfo';
+import { ResourceGraph } from '../../core/ResourceGraph';
 
 const StyledDialog = withStyles({
     paper: {
@@ -42,7 +43,8 @@ const enum Page {
     NOTEBOOK = 2,
     FILES = 3,
     MACHINE = 4,
-    TERMINAL = 5,
+    LOG = 5,
+    GRAPH = 6,
 }
 
 interface IProps {
@@ -96,10 +98,29 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
         window.open('http://' + window.location.hostname + ':' + this.props.app.sessionPort + '?token=' + this.props.app.sessionToken, '_blank');
     }
 
-    private openAsNewNotebook = () => {
-        const path = this.props.app.path.replace('.ipynb', '-' + (this.props.app.annotationOrRunNum.replace(/\W/g, '')) + '.ipynb');
-        var notebook: any = this.props.app.notebook;
-        FileServerUtils.saveNotebook(path, notebook).then((success: boolean) => { Global.docManager.open(path) });
+    private openAsNewNotebook = async () => {
+        const app = this.props.app;
+        var path = app.path.replace('.ipynb', '-' + (app.annotationOrRunNum.replace(/\W/g, '')) + '.ipynb');
+        
+        var inc = 0;
+        var newPath = path;
+        while ((await FileServerUtils.checkIfPathExists(newPath))[0]) {
+            inc++;
+            newPath = inc == 0 ? path : path.replace('.', '(' + inc + ').');
+        }
+
+        if (app.interactive) {
+            const module = app.modules[0];
+            for (let file of module.files) {
+                if (file.path === '~/' + app.path) {
+                    Global.user.fileTracker.downloadFiles(app.path, [file], false, [newPath]).then(() => { Global.docManager.open(newPath) });
+                }
+            }
+        } else {
+            var notebook: any = app.notebook;
+            FileServerUtils.saveNotebook(newPath, notebook).then((success: boolean) => { Global.docManager.open(newPath) });
+        }
+        
         // Close the dialog
         this.handleClose();
     }
@@ -172,21 +193,19 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     Open session
                                 </Button>
                             )}
-                            {!app.interactive && (
-                                <ExtraInfo reminder='Create as a new notebook' >
-                                    <Button
-                                        style={{margin: '6px'}}
-                                        disableElevation
-                                        variant='contained'
-                                        color='primary'
-                                        onClick={this.openAsNewNotebook}
-                                        disabled={app.getAppStatus() != Status.COMPLETED}
-                                        endIcon={<OpenInNewIcon />}
-                                    >
-                                        Save + Open
-                                    </Button>
-                                </ExtraInfo>
-                            )}
+                            <ExtraInfo reminder='Create as a new notebook' >
+                                <Button
+                                    style={{margin: '6px'}}
+                                    disableElevation
+                                    variant='contained'
+                                    color='primary'
+                                    onClick={this.openAsNewNotebook}
+                                    disabled={app.getAppStatus() != Status.COMPLETED}
+                                    endIcon={<OpenInNewIcon />}
+                                >
+                                    Save + Open
+                                </Button>
+                            </ExtraInfo>
 						</div>
                         <IconButton
                             onClick={this.handleClose}
@@ -257,6 +276,15 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                             }}
                                             value={Page.FILES}
                                         />
+                                        {/* <Tab
+                                            label='NEW_FILES'
+                                            style={{
+                                                padding: '0px',
+                                                minWidth: 'auto',
+                                                minHeight: '36px',
+                                            }}
+                                            value={Page.NEW_FILES}
+                                        /> */}
                                         <Tab
                                             label='MACHINE'
                                             style={{
@@ -267,13 +295,22 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                             value={Page.MACHINE}
                                         />
                                         {app.modules.length > 0 && /*app.interactive &&*/ <Tab
-                                            label='TERMINAL'
+                                            label='LOG'
                                             style={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
                                                 minHeight: '36px',
                                             }}
-                                            value={Page.TERMINAL}
+                                            value={Page.LOG}
+                                        />}
+                                        {Global.user.showMonitoringEnabled && <Tab
+                                            label='GRAPH'
+                                            style={{
+                                                padding: '0px',
+                                                minWidth: 'auto',
+                                                minHeight: '36px',
+                                            }}
+                                            value={Page.GRAPH}
                                         />}
                                     </Tabs>
                                 </div>
@@ -335,7 +372,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                             handleClose={this.handleClose}
                                         />
                                     </div>
-                            ) : this.state.selectedPanel == Page.NOTEBOOK ? (
+                                ) : this.state.selectedPanel == Page.NOTEBOOK ? (
                                     <div style={{overflow: 'auto', width: '100%', height: '100%'}}>
                                         <Notebook notebook={app.notebook} />
                                     </div>
@@ -360,13 +397,17 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                         )}
                                     </div>
                                     
-								) : this.state.selectedPanel == Page.TERMINAL && (
+								) : this.state.selectedPanel == Page.LOG ? (
                                     <div style={{overflow: 'hidden', width: '100%', height: '100%'}}>
                                         <ScrollableDiv
                                             key='output'
-                                            source={Object.assign([], app.modules[0].output)}
+                                            source={Object.assign([], app.modules[0].output.filter(x => !x.line.startsWith('  warnings.warn(')))}
                                             autoScroll={true}
                                         />
+                                    </div>
+								) : this.state.selectedPanel == Page.GRAPH && (
+                                    <div style={{overflow: 'hidden', width: '100%', height: '100%'}}>
+                                        {app.modules.map(module => <ResourceGraph key={module.uuid} app={app} />)}
                                     </div>
 								)}
                             </DialogContent>
